# Python ed2k hash module.

## Installation

You can install from [pypi](https://pypi.org/project/ed2k/)

```console
pip install -U ed2k
```

## Usage

### Module

```python
import ed2k
```

### Command

```console
$ ed2k -h
usage: ed2k [-h] [-v] [path ...]

calculate file ed2k hash

positional arguments:
  path           file path(s) to be downloaded, if omitted, read from stdin (one path per line)

options:
  -h, --help     show this help message and exit
  -v, --version  print the current version
```
